SWDEV-339113 - Update sampl codes with correct kernel coordinate (#2704)

Change-Id: Ibfc0fd285441cd3d79b312d2b739729a039a6f84
이 커밋은 다음에 포함됨:
ROCm CI Service Account
2022-06-02 17:07:52 +05:30
커밋한 사람 GitHub
부모 f6f8a0d144
커밋 e6ded45898
14개의 변경된 파일47개의 추가작업 그리고 47개의 파일을 삭제
+2 -2
파일 보기
@@ -35,8 +35,8 @@ THE SOFTWARE.
// Device (Kernel) function, it must be void
__global__ void matrixTranspose(float* out, float* in, const int width) {
int x = hipBlockDim_x * hipBlockIdx_x + hipThreadIdx_x;
int y = hipBlockDim_y * hipBlockIdx_y + hipThreadIdx_y;
int x = blockDim.x * blockIdx.x + threadIdx.x;
int y = blockDim.y * blockIdx.y + threadIdx.y;
asm volatile("v_mov_b32_e32 %0, %1" : "=v"(out[x * width + y]) : "v"(in[y * width + x]));
}